==> pgcalc2-2.2-4.tar.gz: pgcalc2-2.2-4/src/tpgsystemtray.cpp <==
/***************************************************************************
                          tpgsystemtray.cpp  -  description
                             -------------------
    begin                : pi? mar 26 2004
    copyright            : (C) 2004 by Piotr Gridniew
    email                : gridniew@pgcalc.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#include "kapplication.h"
#include "qcanvas.h"
#include "qpainter.h"
#include "qdir.h"
#include "qtooltip.h"
#include <kglobal.h>
#include <kiconloader.h>

#include "tpgsystemtray.h"
#include "pgcalc.h"

TPGSystemTray::TPGSystemTray( TCalc* parent, const char* name )
   : KSystemTray( parent, name )
{
	QString icopath;
   Owner = parent;
	
	KIconLoader *loader = KGlobal::iconLoader();
   QPixmap ico = loader->loadIcon("pgcalc2", KIcon::Desktop, 24, KIcon::DefaultState, &icopath ); //QPixmap( MainPath + QString( "/bin/pgcalc2-24.xpm" ) );
	
	//fprintf( stderr, "Ico Path [%s]...\n", (const char*)( icopath ) );
	
   setPixmap( ico ); //kapp->miniIcon() );
   QToolTip::add( this, kapp->caption() );
}

TPGSystemTray::~TPGSystemTray()
{
}

==> pgcalc2-2.2-10.tar.gz: pgcalc2-2.2-10/src/tpgsystemtray.cpp <==
/***************************************************************************
                          tpgsystemtray.cpp  -  description
                             -------------------
    begin                : pi? mar 26 2004
    copyright            : (C) 2004 by Piotr Gridniew
    email                : gridniew@pgcalc.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#include "kapplication.h"
#include "qcanvas.h"
#include "qpainter.h"
#include "qdir.h"
#include "qtooltip.h"
#include <kglobal.h>
#include <kiconloader.h>

#include "tpgsystemtray.h"
#include "pgcalc.h"

TPGSystemTray::TPGSystemTray( TCalc* parent, const char* name )
   : KSystemTray( parent, name )
{
	QString icopath;
   Owner = parent;
	
	KIconLoader *loader = KGlobal::iconLoader();
   QPixmap ico = loader->loadIcon("pgcalc2", KIcon::Desktop, 24, KIcon::DefaultState, &icopath ); //QPixmap( MainPath + QString( "/bin/pgcalc2-24.xpm" ) );
	
	#ifdef __DEBUG__
	fprintf( stderr, "Ico Path [%s]...\n", (const char*)( icopath ) );
	#endif
	
   setPixmap( ico ); //kapp->miniIcon() );
   QToolTip::add( this, kapp->caption() );
}

TPGSystemTray::~TPGSystemTray()
{
}
